.. spead2 documentation master file, created by
   sphinx-quickstart on Mon Mar 30 09:28:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to spead2's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   py
   cpp
   perf
   tools
   changelog
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
